package ch.rakudave.jnetmap.plugins;

import java.awt.BorderLayout;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import net.xeoh.plugins.base.annotations.PluginImplementation;
import ch.rakudave.jnetmap.model.device.Device;
import ch.rakudave.jnetmap.util.Icons;
import ch.rakudave.jnetmap.util.Lang;
import ch.rakudave.jnetmap.view.preferences.PreferencePanel;

/**
 * A sidebar-panel to store notes for devices
 * @author rakudave
 */
@PluginImplementation
public class NotePanel implements SidebarPlugin {
	private Device d;
	private JLabel title;
	private JTextArea text;	

	@Override public void graphReleased(Device arg0, MouseEvent arg1) {}
	@Override public void graphPressed(Device arg0, MouseEvent arg1) {}
	@Override
	public void graphClicked(Device arg0, MouseEvent arg1) {
		if (d != null) d.setMetadata("notes", text.getText());
		d = arg0;
		title.setText(d.getName());
		text.setText(d.getMetadata("notes"));
	}

	@Override
	public String getPluginName() {
		return Lang.getNoHTML("notepanel.title")+" Panel";
	}

	@Override
	public String getAuthor() {
		return "rakudave";
	}

	@Override
	public String getDescription() {
		return "Enables you to store notes about individual devices";
	}

	@Override
	public Icon getIcon() {
		return Icons.get("notes");
	}

	@Override
	public boolean hasSettings() {
		return false;
	}

	@Override
	public PreferencePanel getSettingsPanel() {
		return null;
	}

	@Override
	public JPanel getPanel() {
		JPanel p = new JPanel(new BorderLayout(0, 5));
		p.setBorder(BorderFactory.createEmptyBorder(3, 3, 3, 3));
			title = new JLabel("-", JLabel.LEADING);
			text = new JTextArea();
				text.setLineWrap(true);
				text.setWrapStyleWord(true);
				text.addFocusListener(new FocusListener() {
					@Override
					public void focusLost(FocusEvent e) {
						if (d != null) d.setMetadata("notes", text.getText());
					}
					@Override public void focusGained(FocusEvent e) {}
				});
		p.add(title, BorderLayout.NORTH);
		p.add(new JScrollPane(text, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
				JScrollPane.HORIZONTAL_SCROLLBAR_NEVER), BorderLayout.CENTER);
		return p;
	}

	@Override
	public String getTabTitle() {
		return Lang.get("notepanel.title");
	}

	@Override
	public String getToolTip() {
		return "";
	}
}
